mirte
=====

``mirte`` is a runtime module framework for Python --- it allows you to write
your application in modules and knit them together at runtime.

Installation
------------

::

    $ pip install mirte

